@@ -241,15 +241,15 @@ class FeatureEngineering:
                             continue
             cats = []
             numeric = []
-            if not cat_cols == None:
+            if not cat_cols:
                 cats = cat_cols
-            if not numeric_cols == None:
+            if not numeric_cols:
                 numeric = numeric_cols
             if not cats:
                 cats = self.identify_cats(data, thresh_cat)
             if not numeric:
                 numeric = self.identify_numeric(data, thresh_numeric)
-            if not method_cat == "None":
+            if not method_cat:
                 for col in cats:
                     if method_cat == 'Mode':
                         data[col].fillna(data[col].mode()[0],inplace=True)
@@ -257,7 +257,7 @@ class FeatureEngineering:
                         data[col].fillna(-9999,inplace=True)
                     else:
                         data[col].interpolate(method ='linear', limit_direction ='forward', inplace=True)
-            if not method_num == "None":
+            if not method_num:
                 for col in numeric:
                     data[col] = data[col].astype('float')
                     if method_num == 'Mean':
@@ -303,11 +303,14 @@ class FeatureEngineering:
         '''
         try:
             cats = []
-            if cat_cols == None:
+            if cat_cols:
                 cats = self.identify_cats(data, thresh)
-            encoder = None
+            
+	    else:
+		cats = cat_cols
+	    encoder = None
             if method == 'BackwardDifferenceEncoder':
-                encoder = BackwardDifferenceEncoder(cols=[...])
+                encoder = BackwardDifferenceEncoder(cols=cats)
             if method == 'BaseNEncoder':
                 encoder = BaseNEncoder(cols=cats)
             if method == 'BinaryEncoder':
@@ -369,8 +372,10 @@ class FeatureEngineering:
         '''
         try:
             num_c = []
-            if numeric_cols == None:
+            if numeric_cols:
                 num_c = self.identify_numeric(data, thresh_numeric)
+	    else:
+		num_c = numeric_cols
             table1 = plot_table(data, num_c)
             scaler = None
             if method == 'LogTransform':
